==> ec2-1.15.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/IInstance.java <==
package software.amazon.awscdk.services.ec2;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.19.0 (build 7c562bc)", date = "2019-10-28T12:23:14.064Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IInstance extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.core.IResource, software.amazon.awscdk.services.ec2.IConnectable, software.amazon.awscdk.services.iam.IGrantable {

    /**
     * The availability zone the instance was launched in.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getInstanceAvailabilityZone();

    /**
     * The instance's ID.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getInstanceId();

    /**
     * Private DNS name for this instance.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getInstancePrivateDnsName();

    /**
     * Private IP for this instance.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getInstancePrivateIp();

    /**
     * Publicly-routable DNS name for this instance.
     * 
     * (May be an empty string if the instance does not have a public name).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getInstancePublicDnsName();

    /**
     * Publicly-routable IP  address for this instance.
     * 
     * (May be an empty string if the instance does not have a public IP).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getInstancePublicIp();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.IInstance {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.setObjRef(objRef);
        }

        /**
         * The availability zone the instance was launched in.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getInstanceAvailabilityZone() {
            return this.jsiiGet("instanceAvailabilityZone", java.lang.String.class);
        }

        /**
         * The instance's ID.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getInstanceId() {
            return this.jsiiGet("instanceId", java.lang.String.class);
        }

        /**
         * Private DNS name for this instance.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getInstancePrivateDnsName() {
            return this.jsiiGet("instancePrivateDnsName", java.lang.String.class);
        }

        /**
         * Private IP for this instance.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getInstancePrivateIp() {
            return this.jsiiGet("instancePrivateIp", java.lang.String.class);
        }

        /**
         * Publicly-routable DNS name for this instance.
         * 
         * (May be an empty string if the instance does not have a public name).
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getInstancePublicDnsName() {
            return this.jsiiGet("instancePublicDnsName", java.lang.String.class);
        }

        /**
         * Publicly-routable IP  address for this instance.
         * 
         * (May be an empty string if the instance does not have a public IP).
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getInstancePublicIp() {
            return this.jsiiGet("instancePublicIp", java.lang.String.class);
        }

        /**
         * The stack in which this resource is defined.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.Stack getStack() {
            return this.jsiiGet("stack", software.amazon.awscdk.core.Stack.class);
        }

        /**
         * The construct node in the tree.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.ConstructNode getNode() {
            return this.jsiiGet("node", software.amazon.awscdk.core.ConstructNode.class);
        }

        /**
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.services.ec2.Connections getConnections() {
            return this.jsiiGet("connections", software.amazon.awscdk.services.ec2.Connections.class);
        }

        /**
         * The principal to grant permissions to.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.services.iam.IPrincipal getGrantPrincipal() {
            return this.jsiiGet("grantPrincipal", software.amazon.awscdk.services.iam.IPrincipal.class);
        }
    }
}

==> ec2-1.16.0.DEVPREVIEW-sources.jar: software/amazon/awscdk/services/ec2/IInstance.java <==
package software.amazon.awscdk.services.ec2;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/0.20.2 (build faba0be)", date = "2019-11-11T17:17:50.801Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.ec2.$Module.class, fqn = "@aws-cdk/aws-ec2.IInstance")
@software.amazon.jsii.Jsii.Proxy(IInstance.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface IInstance extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.core.IResource, software.amazon.awscdk.services.ec2.IConnectable, software.amazon.awscdk.services.iam.IGrantable {

    /**
     * The availability zone the instance was launched in.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getInstanceAvailabilityZone();

    /**
     * The instance's ID.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getInstanceId();

    /**
     * Private DNS name for this instance.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getInstancePrivateDnsName();

    /**
     * Private IP for this instance.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getInstancePrivateIp();

    /**
     * Publicly-routable DNS name for this instance.
     * 
     * (May be an empty string if the instance does not have a public name).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getInstancePublicDnsName();

    /**
     * Publicly-routable IP  address for this instance.
     * 
     * (May be an empty string if the instance does not have a public IP).
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    java.lang.String getInstancePublicIp();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    final static class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.services.ec2.IInstance {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * The availability zone the instance was launched in.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getInstanceAvailabilityZone() {
            return this.jsiiGet("instanceAvailabilityZone", java.lang.String.class);
        }

        /**
         * The instance's ID.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getInstanceId() {
            return this.jsiiGet("instanceId", java.lang.String.class);
        }

        /**
         * Private DNS name for this instance.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getInstancePrivateDnsName() {
            return this.jsiiGet("instancePrivateDnsName", java.lang.String.class);
        }

        /**
         * Private IP for this instance.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getInstancePrivateIp() {
            return this.jsiiGet("instancePrivateIp", java.lang.String.class);
        }

        /**
         * Publicly-routable DNS name for this instance.
         * 
         * (May be an empty string if the instance does not have a public name).
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getInstancePublicDnsName() {
            return this.jsiiGet("instancePublicDnsName", java.lang.String.class);
        }

        /**
         * Publicly-routable IP  address for this instance.
         * 
         * (May be an empty string if the instance does not have a public IP).
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public java.lang.String getInstancePublicIp() {
            return this.jsiiGet("instancePublicIp", java.lang.String.class);
        }

        /**
         * The stack in which this resource is defined.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.Stack getStack() {
            return this.jsiiGet("stack", software.amazon.awscdk.core.Stack.class);
        }

        /**
         * The construct node in the tree.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.core.ConstructNode getNode() {
            return this.jsiiGet("node", software.amazon.awscdk.core.ConstructNode.class);
        }

        /**
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.services.ec2.Connections getConnections() {
            return this.jsiiGet("connections", software.amazon.awscdk.services.ec2.Connections.class);
        }

        /**
         * The principal to grant permissions to.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public software.amazon.awscdk.services.iam.IPrincipal getGrantPrincipal() {
            return this.jsiiGet("grantPrincipal", software.amazon.awscdk.services.iam.IPrincipal.class);
        }
    }
}
